[yt-svn] commit/yt: brittonsmith: Manually preventing njobs from being anything other than -1 in

Bitbucket commits-noreply at bitbucket.org
Wed Oct 17 11:21:10 PDT 2012


1 new commit in yt:


https://bitbucket.org/yt_analysis/yt/changeset/75eab6836b44/
changeset:   75eab6836b44
branch:      yt
user:        brittonsmith
date:        2012-10-16 22:54:02
summary:     Manually preventing njobs from being anything other than -1 in
make_projections and adding a warning if it is not set that way.
affected #:  1 file

diff -r ff017cd2c1a8a85e5894d78b8bbf5745a84dc959 -r 75eab6836b445eb7fe75017d761b06ae63172310 yt/analysis_modules/halo_profiler/multi_halo_profiler.py
--- a/yt/analysis_modules/halo_profiler/multi_halo_profiler.py
+++ b/yt/analysis_modules/halo_profiler/multi_halo_profiler.py
@@ -718,7 +718,9 @@
             Default=True.
         njobs : int
             The number of jobs over which to split the projections.  Set
-            to -1 so that each halo is done by a single processor.
+            to -1 so that each halo is done by a single processor.  Halo 
+            projections do not currently work in parallel, so this must 
+            be set to -1.
             Default: -1.
         dynamic : bool
             If True, distribute halos using a task queue.  If False,
@@ -732,6 +734,12 @@
 
         """
 
+        # Halo projections cannot run in parallel because they are done by 
+        # giving a data source to the projection object.
+        if njobs > 0:
+            mylog.warn("Halo projections cannot use more than one processor per halo, setting njobs to -1.")
+            njobs = -1
+        
         # Get list of halos for projecting.
         if halo_list == 'filtered':
             halo_projection_list = self.filtered_halos

Repository URL: https://bitbucket.org/yt_analysis/yt/

--

This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.



More information about the yt-svn mailing list